@@ -12,7 +12,7 @@
 
    ---------------------------------------------------------------------------
 
-   Copyright (C) 2003,2004,2005,2006  Volker C. Behr
+   Copyright (C) 2003-2007  Volker C. Behr
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,6 +38,11 @@
 
   
    HISTORY: 
+   2007-05-04 : 2.4.6      - optimized default options for GS to produce PDFs
+   2007-02-27 : 2.4.5      - enclosing parentheses () are removed from title,
+                             set a more comprehensive identification string
+   2007-02-02 : 2.4.4      - DOS-style path separators '\' are now recognized
+   2006-11-22 : 2.4.3      - replaced 'setenv' by 'putenv' to increase compatibility
    2006-09-30 : 2.4.2      - several code opimizations,
                              PostScript PPD now uncompressed and rev4 only
    2006-06-13 : 2.4.1      - added a PDF-to-mail postprocessing script to contrib/,
@@ -469,11 +474,21 @@ static int preparetitle(char *title) {
     if (is_ps_hex_string(title))
       decode_ps_hex_string(title);
   }
+  if (strlen(title) && title[0]=='(' && title[strlen(title)-1]==')') {
+    log_event(CPDEBUG, "removing enclosing parentheses () from full title", title);
+    title[strlen(title)-1]='\0';
+    memmove(title, title+1, strlen(title));
+  }
   cut=strrchr(title, '/');
   if (cut != NULL) {
     log_event(CPDEBUG, "removing slashes from full title", title);
     memmove(title, cut+1, strlen(cut+1)+1);
   }  
+  cut=strrchr(title, '\\');
+  if (cut != NULL) {
+    log_event(CPDEBUG, "removing backslashes from full title", title);
+    memmove(title, cut+1, strlen(cut+1)+1);
+  }
   cut=strrchr(title, '.');
   if ((cut != NULL) && ((int)strlen(cut) <= conf.cut+1) && (cut != title)) {
     log_event(CPDEBUG, "removing file name extension", cut);
@@ -601,7 +616,7 @@ int main(int argc, char *argv[]) {
   log_event(CPDEBUG, "initialization finished", CPVERSION);
 
   if (argc==1) {
-    printf("file cups-pdf:/ \"PDF Printer\" \"Virtual Printer\"\n"); 
+    printf("file cups-pdf:/ \"Virtual PDF Printer\" \"CUPS-PDF\"\n"); 
     log_event(CPSTATUS, "identification string sent", NULL);
     return 0;
   }
@@ -750,7 +765,7 @@ int main(int argc, char *argv[]) {
   (void) unlink(outfile);
   log_event(CPDEBUG, "output file unlinked", outfile);
 
-  if (setenv("TMPDIR", conf.gstmp, 1)) {
+  if (putenv(conf.gstmp)) {
     log_event(CPERROR, "insufficient space in environment to set TMPDIR", conf.gstmp);
     free(dirname);
     free(spoolfile);
